@@ -100,58 +100,22 @@ Closes the handle associated with the file descriptoer L</"FD">.
 
 This method is implemented in a child class.
 
-=head2 read
+=head2 sysread
 
-C<method read : int ($string : mutable string, $length : int = -1, $offset : int = 0);>
+C<method sysread : int ($string : mutable string, $length : int = -1, $offset : int = 0);>
 
 Reads the length $length of data from the stream associated with the file descriptoer L</"FD"> and store it to the offset $offset position of the string $string.
 
 And returns the read length.
 
-This method is implemented in a child class.
+=head2 syswrite
 
-=head2 write
-
-C<method write : int ($string : string, $length : int = -1, $offset : int = 0);>
+C<method syswrite : int ($string : string, $length : int = -1, $offset : int = 0);>
 
 Writes the length $length from the offset $offset of the string $string to the stream associated with the file descriptoer L</"FD">.
 
 And returns the write length.
 
-This method is implemented in a child class.
-
-=head2 print
-
-C<method print : void ($string : string);>
-
-Outputs the string $string to the stream associated with the file descriptoer L</"FD">.
-
-Same as the following method call.
-
-  $handle->write($string);
-
-=head2 printf
-
-C<method printf : void ($format : string, $args : object[]...);>
-
-Outputs a string fomatted with the format $format and its parameters $args to the stream associated with the file descriptoer L</"FD">.
-
-Same as the following method call.
-
-  my $formated_string = Format->sprintf($format, $args);
-  $handle->print($formated_string);
-
-=head2 say
-
-C<method say : void ($string : string);>
-
-Outputs the string $string and C<\n> to the stream associated with the file descriptoer L</"FD">.
-
-Same as the following method call.
-
-  $handle->print($string);
-  $handle->print("\n");
-
 =head2 stat
 
 C<method stat : Sys::IO::Stat ();>
